
# Changelog
All notable changes to WuttaPOS will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

## v0.2.1 (2024-07-01)

### Fix

- use rattail function to create top-level command

## v0.2.0 (2024-06-10)

### Feat

- switch from setup.cfg to pyproject.toml + hatchling

## [0.1.0] - 2023-09-22
### Added
- Initial version (WIP; testing only).
